@@ -4,7 +4,7 @@
 Copyright 1989, 1998  The Open Group
 
 Permission to use, copy, modify, distribute, and sell this software and its
-Documentation for any purpose is hereby granted without fee, provided that
+documentation for any purpose is hereby granted without fee, provided that
 the above copyright notice appear in all copies and that both that
 copyright notice and this permission notice appear in supporting
 documentation.
@@ -26,19 +26,20 @@ other dealings in this Software without prior written authorization
 from The Open Group.
 
 */
+/* $XFree86: xc/programs/xauth/process.c,v 3.18 2003/02/13 02:50:22 dawes Exp $ */
 
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001,2003 NoMachine, http://www.nomachine.com.           */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXAUTH, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -60,7 +61,7 @@ from The Open Group.
 #include <X11/extensions/security.h>
 */
 
-/*FIXME EMANUELE*/
+/*FIXME*/
 #define FamilyInternet              0  
 #define FamilyDECnet                1
 
@@ -164,7 +165,7 @@ static CommandTable command_table[] = {	/* table of known commands */
     { "?",        1, 1, do_questionmark,
 	"?                              list available commands" },
 /*    { "generate", 1, 8, do_generate,
-	"generate dpyname protoname [options]  use server to generate entry\n"
+	"generate dpyname protoname [options]  use server to generate entry\n" 
         "    options are:\n"
         "      timeout n    authorization expiration time in seconds\n"
         "      trusted      clients using this entry are trusted\n"
@@ -181,38 +182,38 @@ static CommandTable command_table[] = {	/* table of known commands */
 static Bool okay_to_use_stdin = True;	/* set to false after using */
 
 static char *hex_table[] = {		/* for printing hex digits */
-    "00", "01", "02", "03", "04", "05", "06", "07",
-    "08", "09", "0a", "0b", "0c", "0d", "0e", "0f",
-    "10", "11", "12", "13", "14", "15", "16", "17",
-    "18", "19", "1a", "1b", "1c", "1d", "1e", "1f",
-    "20", "21", "22", "23", "24", "25", "26", "27",
-    "28", "29", "2a", "2b", "2c", "2d", "2e", "2f",
-    "30", "31", "32", "33", "34", "35", "36", "37",
-    "38", "39", "3a", "3b", "3c", "3d", "3e", "3f",
-    "40", "41", "42", "43", "44", "45", "46", "47",
-    "48", "49", "4a", "4b", "4c", "4d", "4e", "4f",
-    "50", "51", "52", "53", "54", "55", "56", "57",
-    "58", "59", "5a", "5b", "5c", "5d", "5e", "5f",
-    "60", "61", "62", "63", "64", "65", "66", "67",
-    "68", "69", "6a", "6b", "6c", "6d", "6e", "6f",
-    "70", "71", "72", "73", "74", "75", "76", "77",
-    "78", "79", "7a", "7b", "7c", "7d", "7e", "7f",
-    "80", "81", "82", "83", "84", "85", "86", "87",
-    "88", "89", "8a", "8b", "8c", "8d", "8e", "8f",
-    "90", "91", "92", "93", "94", "95", "96", "97",
-    "98", "99", "9a", "9b", "9c", "9d", "9e", "9f",
-    "a0", "a1", "a2", "a3", "a4", "a5", "a6", "a7",
-    "a8", "a9", "aa", "ab", "ac", "ad", "ae", "af",
-    "b0", "b1", "b2", "b3", "b4", "b5", "b6", "b7",
-    "b8", "b9", "ba", "bb", "bc", "bd", "be", "bf",
-    "c0", "c1", "c2", "c3", "c4", "c5", "c6", "c7",
-    "c8", "c9", "ca", "cb", "cc", "cd", "ce", "cf",
-    "d0", "d1", "d2", "d3", "d4", "d5", "d6", "d7",
-    "d8", "d9", "da", "db", "dc", "dd", "de", "df",
-    "e0", "e1", "e2", "e3", "e4", "e5", "e6", "e7",
-    "e8", "e9", "ea", "eb", "ec", "ed", "ee", "ef",
-    "f0", "f1", "f2", "f3", "f4", "f5", "f6", "f7",
-    "f8", "f9", "fa", "fb", "fc", "fd", "fe", "ff",
+    "00", "01", "02", "03", "04", "05", "06", "07", 
+    "08", "09", "0a", "0b", "0c", "0d", "0e", "0f", 
+    "10", "11", "12", "13", "14", "15", "16", "17", 
+    "18", "19", "1a", "1b", "1c", "1d", "1e", "1f", 
+    "20", "21", "22", "23", "24", "25", "26", "27", 
+    "28", "29", "2a", "2b", "2c", "2d", "2e", "2f", 
+    "30", "31", "32", "33", "34", "35", "36", "37", 
+    "38", "39", "3a", "3b", "3c", "3d", "3e", "3f", 
+    "40", "41", "42", "43", "44", "45", "46", "47", 
+    "48", "49", "4a", "4b", "4c", "4d", "4e", "4f", 
+    "50", "51", "52", "53", "54", "55", "56", "57", 
+    "58", "59", "5a", "5b", "5c", "5d", "5e", "5f", 
+    "60", "61", "62", "63", "64", "65", "66", "67", 
+    "68", "69", "6a", "6b", "6c", "6d", "6e", "6f", 
+    "70", "71", "72", "73", "74", "75", "76", "77", 
+    "78", "79", "7a", "7b", "7c", "7d", "7e", "7f", 
+    "80", "81", "82", "83", "84", "85", "86", "87", 
+    "88", "89", "8a", "8b", "8c", "8d", "8e", "8f", 
+    "90", "91", "92", "93", "94", "95", "96", "97", 
+    "98", "99", "9a", "9b", "9c", "9d", "9e", "9f", 
+    "a0", "a1", "a2", "a3", "a4", "a5", "a6", "a7", 
+    "a8", "a9", "aa", "ab", "ac", "ad", "ae", "af", 
+    "b0", "b1", "b2", "b3", "b4", "b5", "b6", "b7", 
+    "b8", "b9", "ba", "bb", "bc", "bd", "be", "bf", 
+    "c0", "c1", "c2", "c3", "c4", "c5", "c6", "c7", 
+    "c8", "c9", "ca", "cb", "cc", "cd", "ce", "cf", 
+    "d0", "d1", "d2", "d3", "d4", "d5", "d6", "d7", 
+    "d8", "d9", "da", "db", "dc", "dd", "de", "df", 
+    "e0", "e1", "e2", "e3", "e4", "e5", "e6", "e7", 
+    "e8", "e9", "ea", "eb", "ec", "ed", "ee", "ef", 
+    "f0", "f1", "f2", "f3", "f4", "f5", "f6", "f7", 
+    "f8", "f9", "fa", "fb", "fc", "fd", "fe", "ff", 
 };
 
 static unsigned int hexvalues[256];	/* for parsing hex input */
@@ -224,20 +225,20 @@ static int original_umask = 0;		/* for restoring */
  * private utility procedures
  */
 
-static void
+static void 
 prefix(char *fn, int n)
 {
     fprintf (stderr, "%s: %s:%d:  ", ProgramName, fn, n);
 }
 
-static void
+static void 
 baddisplayname(char *dpy, char *cmd)
 {
     fprintf (stderr, "bad display name \"%s\" in \"%s\" command\n",
 	     dpy, cmd);
 }
 
-static void
+static void 
 badcommandline(char *cmd)
 {
     fprintf (stderr, "bad \"%s\" command line\n", cmd);
@@ -307,11 +308,11 @@ split_into_words(char *src, int *argcp)  /* argvify string */
 
 
 static FILE *
-open_file(char **filenamep,
-	  char *mode,
-	  Bool *usedstdp,
-	  char *srcfn,
-	  int srcln,
+open_file(char **filenamep, 
+	  char *mode, 
+	  Bool *usedstdp, 
+	  char *srcfn, 
+	  int srcln, 
 	  char *cmd)
 {
     FILE *fp;
@@ -343,7 +344,7 @@ open_file(char **filenamep,
     return fp;
 }
 
-static int
+static int 
 getinput(FILE *fp)
 {
     register int c;
@@ -352,7 +353,7 @@ getinput(FILE *fp)
     return c;
 }
 
-static int
+static int 
 get_short(FILE *fp, unsigned short *sp)	/* for reading numeric input */
 {
     int c;
@@ -436,7 +437,7 @@ read_numeric(FILE *fp)
       goto bad;
     if (!get_bytes (fp, (unsigned int) auth->data_length, &auth->data))
       goto bad;
-
+    
     switch (getinput (fp)) {		/* get end of line */
       case EOF:
       case '\n':
@@ -450,7 +451,7 @@ read_numeric(FILE *fp)
 
 typedef Xauth *(*ReadFunc)(FILE *);
 
-static int
+static int 
 read_auth_entries(FILE *fp, Bool numeric, AuthList **headp, AuthList **tailp)
 {
     ReadFunc readfunc = (numeric ? read_numeric : XauReadAuth);
@@ -483,7 +484,7 @@ read_auth_entries(FILE *fp, Bool numeric, AuthList **headp, AuthList **tailp)
     return n;
 }
 
-static Bool
+static Bool 
 get_displayname_auth(char *displayname, Xauth *auth)
 {
     int family;
@@ -502,6 +503,20 @@ get_displayname_auth(char *displayname, Xauth *auth)
     if (cp && strncmp (cp, "/unix:", 6) == 0)
       prelen = (cp - displayname);
 
+    #ifdef __APPLE__
+
+    /*
+     * FIXME: This is an attempt to get the right
+     * cookie, because no one can grant that the
+     * X server is running on the display number
+     * reported in the launchd display name.
+     */
+
+    if (strncmp (displayname, "/tmp/launch", 11) == 0)
+      displayname = strrchr(displayname, '/') + 1;
+
+    #endif
+
     if (!parse_displayname (displayname + ((prelen > 0) ? prelen + 1 : 0),
 			    &family, &host, &dpynum, &scrnum, &rest)) {
 	return False;
@@ -543,7 +558,7 @@ get_displayname_auth(char *displayname, Xauth *auth)
     }
 }
 
-static int
+static int 
 cvthexkey(char *hexstr, char **ptrp)	/* turn hex key string into octets */
 {
     int i;
@@ -594,12 +609,12 @@ cvthexkey(char *hexstr, char **ptrp)	/* turn hex key string into octets */
     return len;
 }
 
-static int
-dispatch_command(char *inputfilename,
-		 int lineno,
-		 int argc,
-		 char **argv,
-		 CommandTable *tab,
+static int 
+dispatch_command(char *inputfilename, 
+		 int lineno, 
+		 int argc, 
+		 char **argv, 
+		 CommandTable *tab, 
 		 int *statusp)
 {
     CommandTable *ct;
@@ -640,7 +655,7 @@ static Bool dieing = False;
 #define WRITES(fd, S) (void)write((fd), (S), strlen((S)))
 
 /* ARGSUSED */
-static _signal_t
+static _signal_t 
 die(int sig)
 {
     dieing = True;
@@ -651,7 +666,7 @@ die(int sig)
 #endif
 }
 
-static _signal_t
+static _signal_t 
 catchsig(int sig)
 {
 #ifdef SYSV
@@ -673,7 +688,7 @@ catchsig(int sig)
 #endif
 }
 
-static void
+static void 
 register_signals(void)
 {
     signal (SIGINT, catchsig);
@@ -689,7 +704,7 @@ register_signals(void)
  * public procedures for parsing lines of input
  */
 
-int
+int 
 auth_initialize(char *authfilename)
 {
     int n;
@@ -697,7 +712,7 @@ auth_initialize(char *authfilename)
     FILE *authfp;
     Bool exists;
 
-    xauth_filename = authfilename;    /* used in cleanup, prevent race with
+    xauth_filename = authfilename;    /* used in cleanup, prevent race with 
                                          signals */
     register_signals ();
 
@@ -728,7 +743,7 @@ auth_initialize(char *authfilename)
 	if (break_locks) XauUnlockAuth (authfilename);
     } else {
 	n = XauLockAuth (authfilename, XAUTH_DEFAULT_RETRIES,
-			 XAUTH_DEFAULT_TIMEOUT,
+			 XAUTH_DEFAULT_TIMEOUT, 
 			 (break_locks ? 0L : XAUTH_DEFAULT_DEADTIME));
 	if (n != LOCK_SUCCESS) {
 	    char *reason = "unknown error";
@@ -767,7 +782,7 @@ auth_initialize(char *authfilename)
 	    errno = olderrno;
 	    return -1;
 	}				/* else ignore it */
-	fprintf (stderr,
+	fprintf (stderr, 
 		 "%s:  creating new authority file %s\n",
 		 ProgramName, authfilename);
     } else {
@@ -790,17 +805,17 @@ auth_initialize(char *authfilename)
 	fprintf(stderr,"cannot allocate memory\n");
 	return -1;
     }
-
+    
     xauth_modified = False;
 
     if (verbose) {
-	printf ("%s authority file %s\n",
+	printf ("%s authority file %s\n", 
 		ignore_locks ? "Ignoring locks on" : "Using", authfilename);
     }
     return 0;
 }
 
-static int
+static int 
 write_auth_file(char *tmp_nam)
 {
     FILE *fp = NULL;
@@ -821,7 +836,7 @@ write_auth_file(char *tmp_nam)
 	fprintf (stderr, "%s:  unable to open tmp file \"%s\"\n",
 		 ProgramName, tmp_nam);
 	return -1;
-    }
+    } 
 
     /*
      * Write MIT-MAGIC-COOKIE-1 first, because R4 Xlib knows
@@ -850,7 +865,7 @@ write_auth_file(char *tmp_nam)
     return 0;
 }
 
-int
+int 
 auth_finalize(void)
 {
     char temp_name[1024];	/* large filename size */
@@ -874,12 +889,12 @@ auth_finalize(void)
 #endif
 	    }
 	} else if (!xauth_allowed) {
-	    fprintf (stderr,
+	    fprintf (stderr, 
 		     "%s:  %s not writable, changes ignored\n",
 		     ProgramName, xauth_filename);
 	} else {
 	    if (verbose) {
-		printf ("%s authority file %s\n",
+		printf ("%s authority file %s\n", 
 			ignore_locks ? "Ignoring locks and writing" :
 			"Writing", xauth_filename);
 	    }
@@ -890,7 +905,7 @@ auth_finalize(void)
 			 ProgramName, temp_name);
 	    } else {
 		(void) unlink (xauth_filename);
-#if defined(WIN32) || defined(__UNIXOS2__)
+#if defined(WIN32) || defined(__UNIXOS2__)|| defined(__CYGWIN__)
 		if (rename(temp_name, xauth_filename) == -1)
 #else
 		if (link (temp_name, xauth_filename) == -1)
@@ -913,7 +928,7 @@ auth_finalize(void)
     return 0;
 }
 
-int
+int 
 process_command(char *inputfilename, int lineno, int argc, char **argv)
 {
     int status;
@@ -934,13 +949,13 @@ process_command(char *inputfilename, int lineno, int argc, char **argv)
  * utility routines
  */
 
-static char *
+static char * 
 bintohex(unsigned int len, char *bindata)
 {
     char *hexdata, *starthex;
 
     /* two chars per byte, plus null termination */
-    starthex = hexdata = (char *)malloc(2*len + 1);
+    starthex = hexdata = (char *)malloc(2*len + 1); 
     if (!hexdata)
 	return NULL;
 
@@ -953,7 +968,7 @@ bintohex(unsigned int len, char *bindata)
     return starthex;
 }
 
-static void
+static void 
 fprintfhex(register FILE *fp, int len, char *cp)
 {
     char *hex;
@@ -980,7 +995,7 @@ dump_numeric(register FILE *fp, register Xauth *auth)
 }
 
 /* ARGSUSED */
-static int
+static int 
 dump_entry(char *inputfilename, int lineno, Xauth *auth, char *data)
 {
     struct _list_data *ld = (struct _list_data *) data;
@@ -1003,6 +1018,7 @@ dump_entry(char *inputfilename, int lineno, Xauth *auth, char *data)
 		fprintf (fp, "%s", dpyname);
 		break;
 	    }
+	    /* else fall through to default */
 	  default:
 	    fprintf (fp, "#%04x#", auth->family);
 	    fprintfhex (fp, auth->address_length, auth->address);
@@ -1025,7 +1041,7 @@ dump_entry(char *inputfilename, int lineno, Xauth *auth, char *data)
     return 0;
 }
 
-static int
+static int 
 extract_entry(char *inputfilename, int lineno, Xauth *auth, char *data)
 {
     struct _extract_data *ed = (struct _extract_data *) data;
@@ -1050,7 +1066,7 @@ extract_entry(char *inputfilename, int lineno, Xauth *auth, char *data)
 }
 
 
-static int
+static int 
 match_auth_dpy(register Xauth *a, register Xauth *b)
 {
     return ((a->family == b->family &&
@@ -1062,7 +1078,7 @@ match_auth_dpy(register Xauth *a, register Xauth *b)
 
 /* return non-zero iff display and authorization type are the same */
 
-static int
+static int 
 match_auth(register Xauth *a, register Xauth *b)
 {
     return ((match_auth_dpy(a, b)
@@ -1071,7 +1087,7 @@ match_auth(register Xauth *a, register Xauth *b)
 }
 
 
-static int
+static int 
 merge_entries(AuthList **firstp, AuthList *second, int *nnewp, int *nreplp)
 {
     AuthList *a, *b, *first, *tail;
@@ -1137,9 +1153,9 @@ merge_entries(AuthList **firstp, AuthList *second, int *nnewp, int *nreplp)
 
 typedef int (*YesNoFunc)(char *, int, Xauth *, char *);
 
-static int
+static int 
 iterdpy (char *inputfilename, int lineno, int start,
-	 int argc, char *argv[],
+	 int argc, char *argv[], 
 	 YesNoFunc yfunc, YesNoFunc nfunc, char *data)
 {
     int i;
@@ -1189,7 +1205,7 @@ iterdpy (char *inputfilename, int lineno, int start,
 }
 
 /* ARGSUSED */
-static int
+static int 
 remove_entry(char *inputfilename, int lineno, Xauth *auth, char *data)
 {
     int *nremovedp = (int *) data;
@@ -1216,7 +1232,7 @@ remove_entry(char *inputfilename, int lineno, Xauth *auth, char *data)
 /*
  * help
  */
-int
+int 
 print_help(FILE *fp, char *cmd, char *prefix)
 {
     CommandTable *ct;
@@ -1238,11 +1254,11 @@ print_help(FILE *fp, char *cmd, char *prefix)
 	    }
 	}
     }
-
+	
     return n;
 }
 
-static int
+static int 
 do_help(char *inputfilename, int lineno, int argc, char **argv)
 {
     char *cmd = (argc > 1 ? argv[1] : NULL);
@@ -1273,7 +1289,7 @@ do_help(char *inputfilename, int lineno, int argc, char **argv)
  * questionmark
  */
 /* ARGSUSED */
-static int
+static int 
 do_questionmark(char *inputfilename, int lineno, int argc, char **argv)
 {
     CommandTable *ct;
@@ -1308,28 +1324,27 @@ do_questionmark(char *inputfilename, int lineno, int argc, char **argv)
 /*
  * list [displayname ...]
  */
-static int
+static int 
 do_list (char *inputfilename, int lineno, int argc, char **argv)
 {
     struct _list_data ld;
 
     ld.fp = stdout;
     ld.numeric = (argv[0][0] == 'n');
+
     if (argc == 1) {
 	register AuthList *l;
 
 	if (xauth_head) {
 	    for (l = xauth_head; l; l = l->next) {
-		
-                dump_entry (inputfilename, lineno, l->auth, (char *) &ld);
-                
+		dump_entry (inputfilename, lineno, l->auth, (char *) &ld);
 	    }
 	}
 	return 0;
     }
 
-     return iterdpy (inputfilename, lineno, 1, argc, argv,
-			    dump_entry, NULL, (char *) &ld);
+    return iterdpy (inputfilename, lineno, 1, argc, argv,
+		    dump_entry, NULL, (char *) &ld);
     
    return 0;
 }
@@ -1337,7 +1352,7 @@ do_list (char *inputfilename, int lineno, int argc, char **argv)
 /*
  * merge filename [filename ...]
  */
-static int
+static int 
 do_merge(char *inputfilename, int lineno, int argc, char **argv)
 {
     int i;
@@ -1388,8 +1403,8 @@ do_merge(char *inputfilename, int lineno, int argc, char **argv)
      */
     if (listhead) {
 	nentries = merge_entries (&xauth_head, listhead, &nnew, &nrepl);
-	if (verbose)
-	  printf ("%d entries read in:  %d new, %d replacement%s\n",
+	if (verbose) 
+	  printf ("%d entries read in:  %d new, %d replacement%s\n", 
 	  	  nentries, nnew, nrepl, nrepl != 1 ? "s" : "");
 	if (nentries > 0) xauth_modified = True;
     }
@@ -1400,7 +1415,7 @@ do_merge(char *inputfilename, int lineno, int argc, char **argv)
 /*
  * extract filename displayname [displayname ...]
  */
-static int
+static int 
 do_extract(char *inputfilename, int lineno, int argc, char **argv)
 {
     int errors;
@@ -1418,16 +1433,16 @@ do_extract(char *inputfilename, int lineno, int argc, char **argv)
     ed.nwritten = 0;
     ed.cmd = argv[0];
 
-    errors = iterdpy (inputfilename, lineno, 2, argc, argv,
+    errors = iterdpy (inputfilename, lineno, 2, argc, argv, 
 		      extract_entry, NULL, (char *) &ed);
 
     if (!ed.fp) {
-	fprintf (stderr,
+	fprintf (stderr, 
 		 "No matches found, authority file \"%s\" not written\n",
 		 ed.filename);
     } else {
 	if (verbose) {
-	    printf ("%d entries written to \"%s\"\n",
+	    printf ("%d entries written to \"%s\"\n", 
 		    ed.nwritten, ed.filename);
 	}
 	if (!ed.used_stdout) {
@@ -1442,9 +1457,9 @@ do_extract(char *inputfilename, int lineno, int argc, char **argv)
 /*
  * add displayname protocolname hexkey
  */
-static int
+static int 
 do_add(char *inputfilename, int lineno, int argc, char **argv)
-{
+{ 
     int n, nnew, nrepl;
     int len;
     char *dpyname;
@@ -1551,7 +1566,7 @@ do_add(char *inputfilename, int lineno, int argc, char **argv)
 /*
  * remove displayname
  */
-static int
+static int 
 do_remove(char *inputfilename, int lineno, int argc, char **argv)
 {
     int nremoved = 0;
@@ -1572,7 +1587,7 @@ do_remove(char *inputfilename, int lineno, int argc, char **argv)
 /*
  * info
  */
-static int
+static int 
 do_info(char *inputfilename, int lineno, int argc, char **argv)
 {
     int n;
@@ -1604,7 +1619,7 @@ do_info(char *inputfilename, int lineno, int argc, char **argv)
 static Bool alldone = False;
 
 /* ARGSUSED */
-static int
+static int 
 do_exit(char *inputfilename, int lineno, int argc, char **argv)
 {
     /* allow bogus stuff */
@@ -1616,7 +1631,7 @@ do_exit(char *inputfilename, int lineno, int argc, char **argv)
  * quit
  */
 /* ARGSUSED */
-static int
+static int 
 do_quit(char *inputfilename, int lineno, int argc, char **argv)
 {
     /* allow bogus stuff */
@@ -1629,7 +1644,7 @@ do_quit(char *inputfilename, int lineno, int argc, char **argv)
 /*
  * source filename
  */
-static int
+static int 
 do_source(char *inputfilename, int lineno, int argc, char **argv)
 {
     char *script;
@@ -1707,7 +1722,7 @@ catch_x_protocol_error(Display *dpy, XErrorEvent *errevent)
 /*
  * generate
  */
-/*static int
+/*static int 
 do_generate(char *inputfilename, int lineno, int argc, char **argv)
 {
     char *displayname;
@@ -1743,7 +1758,7 @@ do_generate(char *inputfilename, int lineno, int argc, char **argv)
 		prefix (inputfilename, lineno);
 		badcommandline (argv[i-1]);
 		return 1;
-	    }
+	    } 
 	    attributes.timeout = atoi(argv[i]);
 	    attrmask |= XSecurityTimeout;
 
@@ -1760,7 +1775,7 @@ do_generate(char *inputfilename, int lineno, int argc, char **argv)
 		prefix (inputfilename, lineno);
 		badcommandline (argv[i-1]);
 		return 1;
-	    }
+	    } 
 	    attributes.group = atoi(argv[i]);
 	    attrmask |= XSecurityGroup;
 
@@ -1769,7 +1784,7 @@ do_generate(char *inputfilename, int lineno, int argc, char **argv)
 		prefix (inputfilename, lineno);
 		badcommandline (argv[i-1]);
 		return 1;
-	    }
+	    } 
 	    hexdata = argv[i];
 	    authdatalen = strlen(hexdata);
 	    if (hexdata[0] == '"' && hexdata[authdatalen-1] == '"') {
